##  Managing Transformations Associated with Fact Sheets
Transformations detail the actionable changes needed to realize a project. Modeling transformations allows you to preview and contextualize the outcomes of IT initiatives without implementing changes in the baseline (as-is) version of the architecture. The Transformations tab in the fact sheet lists the transformation items related to that fact sheet. Note that it is available only for users of the SAP LeanIX Architecture and Road Map Planning product. To learn how to create, edit, and execute transformations, see [Transformations](https://help.sap.com/docs/leanix/ea/transformations?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to define and manage Transformations in the Initiative Fact Sheet.").
